Authors
=======

`Anatoly Bubenkov <bubenkoff@gmail.com>`_
    initial idea and first alpha implementation
`German Gomez-Herrero <german.gomezherrero@gmail.com>`_
    actual implementation and further developments
